dtiIndices-class: Class "dtiIndices"
Description
Fractional Anisotropy indices and main directions of anisotropy derived from a diffusion tensorObjects from the Class
Objects can be created by calls of function dtiIndices.Extends
Class "list", from data part.
Class "dti", directly.
Class "vector", by class "list", distance 2.References
K. Tabelow, J. Polzehl, H.U. Voss, and V. Spokoiny. Diffusion Tensor Imaging: Structural adaptive smoothing, NeuroImage 39(4), 1763-1773 (2008).http://www.wias-berlin.de/projects/matheon_a3/
Examples
Run this codeshowClass("dtiIndices")
demo(dti_art)
Run the code above in your browser using DataLab