Learn R Programming

dti (version 1.1-4)

awssigmc: Estimate noise variance for multicoil MR systems

Description

The distribution of image intensity values $S_i$ divided by the noise standard deviation in $K$-space $\sigma$ in dMRI experiments is assumed to follow a non-central chi-distribution with $2L$ degrees of freedom and noncentrality parameter $\eta$, where $L$ refers to the number of receiver coils in the system and $\sigma \eta$ is the signal of interest. This is an idealization in the sense that each coil is assumed to have the same contribution at each location. For realistic modeling $L$ should be a locally smooth function in voxel space that reflects the varying local influence of the receiver coils in the the reconstruction algorithm used. The function assumes $L$ to be known and estimates a global $\sigma$ employing an assumption of local homogeneity for the noncentrality parameter $\eta$.

Usage

awssigmc(y, steps, mask = NULL, ncoils = 1, vext = c(1, 1), lambda = 20, h0 = 2, verbose = FALSE, sequence = FALSE, hadj = 1, q = 0.25, qni = .8, method=c("VAR","MAD"))

Arguments

y
3D array, usually obtained from an object of class dwi as obj@si[,,,i] for some i, i.e. one 3D image from an dMRI experiment.
steps
number of steps in adapive weights smoothing, used to reveal the unerlying mean structure.
mask
restrict computations to voxel in mask, if is.null(mask) all voxel are used.
ncoils
number of coils, or equivalently number of effective degrees of freedom of non-central chi distribution divided by 2.
vext
voxel extentions
lambda
scale parameter in adaptive weights smoothing
h0
initial bandwidth
verbose
if verbose==TRUE density plots and quantiles of local estimates of sigma are provided.
sequence
if sequence=TRUE a vector of estimates for the noise standard deviation sigma for the individual steps is returned instead of the final value only.
hadj
adjustment factor for bandwidth (chosen by bw.nrd) in mode estimation
q
quantile to be used for interquantile-differences.
qni
quantile of distribution of actual sum of weights $N_i=\sum_j w_{ij}$ in adaptive smoothing. Only voxel i with $N_i > q_{qni}(N_.)$ are used for variance estimation. Should be larger than 0.5.
method
method for variance estimation, either "VAR" (variance) or "MAD" (mean absolute deviation).

Value

  • a list with components
  • sigmaeither a scalar or a vector of estimated noise standard deviations.
  • thetathe estimated mean structure

References

K. Tabelow and J. Polzehl (2013). Estimating the noise level in MRI using structural adaptive smoothing. Manuscript in preparation.