Usage
awssigmc(y, steps, mask = NULL, ncoils = 1, vext = c(1, 1), lambda = 20,
h0 = 2, verbose = FALSE, sequence = FALSE, hadj = 1, q = 0.25,
qni = .8, method=c("VAR","MAD"))
afsigmc(y, level = NULL, mask = NULL, ncoils = 1, vext = c( 1, 1),
h = 2, verbose = FALSE, hadj = 1,
method = c("modevn","modem1chi","bkm2chi","bkm1chi"))Arguments
y
3D array, usually obtained from an object of class dwi as
obj@si[,,,i] for some i, i.e. one 3D image from an dMRI experiment.
steps
number of steps in adapive weights smoothing, used to reveal the unerlying
mean structure.
mask
restrict computations to voxel in mask, if is.null(mask) all voxel are used.
In function afsigmc mask should refer to background for method %in% c("modem1chi","bkm2chi","bkm1chi") and to voxel within the head for
ncoils
number of coils, or equivalently number of effective degrees of freedom of non-central chi distribution
divided by 2.
lambda
scale parameter in adaptive weights smoothing
verbose
if verbose==TRUE density plots
and quantiles of local estimates of sigma are provided.
sequence
if sequence=TRUE a vector of estimates for the noise
standard deviation sigma for the individual steps is returned
instead of the final value only.
hadj
adjustment factor for bandwidth (chosen by bw.nrd) in mode estimation
q
quantile to be used for interquantile-differences.
qni
quantile of distribution of actual sum of weights $N_i=\sum_j w_{ij}$ in adaptive smoothing. Only voxel i with $N_i > q_{qni}(N_.)$ are used for variance estimation. Should be larger than 0.5.
method
in case of function awssigmc the
method for variance estimation, either "VAR" (variance) or "MAD" (mean absolute deviation). In function afsigmc see last column in Table 2 in Aja-Fernandez (2009).
level
threshold for background separation. Used if !is.null(level)
to redefine mask
h
bandwidth for local avaeraging