Usage
awssigmc(y, steps, mask = NULL, ncoils = 1, vext = c(1, 1), lambda = 10, h0 = 2, verbose = FALSE,
model = "chisq", sequence = FALSE, eps = 1e-05, hadj = 1, q = 0.25)Arguments
y
3D array, usually obtained from an object of class dwi as
obj@si[,,,i] for some i, i.e. one 3D image from an dMRI experiment.
steps
number of steps in adapive weights smoothing, used to reveal the unerlying
mean structure.
mask
restrict computations to voxel in mask, if is.null(mask) all voxel are used.
ncoils
number of coils, or equivalently number of effective degrees of freedom of non-central chi distribution
divided by 2.
lambda
scale parameter in adaptive weights smoothing
verbose
if verbose==TRUE density plots
and quantiles of local estimates of sigma are provided.
model
either "chi" or "chisq". In the latter case
smoothing and variance estimation are performed for y^2
instead of y which is considerably faster.
sequence
if sequence=TRUE a vector of estimates for the noise
standard deviation sigma for the individual steps is returned
instead of the final value only.
eps
accuracy when solving fixpoint equation for noncentrality parameter in case of
model="chi".
hadj
adjustment factor for bandwidth (chosen by bw.nrd) in mode estimation
q
quantile to be used for interquantile-differences.