Learn R Programming

dti (version 0.9-4)

dti-package: DTI Analysis

Description

Diffusion Weighted Imaging (DWI) is a Magnetic Resonance Imaging modality, that measures diffusion of water in tissues like the human brain. The package contains R-functions to process diffusion-weighted data. The functionality includes diffusion tensor imaging (DTI), structural adaptive smoothing in in case of (DTI) (K. Tabelow, J. Polzehl, V. Spokoiny, and H.U. Voss, Diffusion Tensor Imaging: Structural Adaptive Smoothing, Neuroimage 39(4), 1763-1773 (2008)), modeling for high angular resolution diffusion weighted imaging (HARDI) using Q-ball-reconstruction and tensor mixture models and a stremaline fiber tracking for tensor and tensor mixture models. The package provides functionality to manipulate and visualize results in 2D and 3D.

Arguments

Details

ll{ Package: dti Version: 0.9-3 Date: 2010-10-21 Depends: R (>= 2.5.0), adimpro, fmri, rgl License: GPL (>=2) Copyright: 2008-2010 Weierstrass Institute for Applied Analysis and Stochastics. URL: http://www.wias-berlin.de/projects/matheon_a3 }

The package is based on S4 classes and methods. For help on a specific topic use class ? for classes, methods ? for methods and ? for all other functions.

Index: dti-class Classes "dti", "dtiData", "dtiTensor", "dtiIndices", "dwiQball", "dwiMixtensor" and "dwiFiber"

dtiData Read Diffusion Weighted Data from Image File readDWIdata Read Diffusion Weighted Data from Directory

dti.smooth Structural Adaptive Smoothing

dtiTensor-methods Methods for Function 'dtiTensor' dtiIndices-methods Methods for Function 'dtiIndices'

dwiQball-methods Methods for Function 'dwiQball' dwiMixtensor-methods Methods for Function 'dwiMixtensor'

extract-methods Methods for Functions 'extract' and "[" plot-methods Methods for Function 'plot' show-methods Methods for Function 'show' show3d-methods Methods for Function 'show3d' print-methods Methods for Function 'print' summary-methods Methods for Function 'summary'

tracking-methods Methods for Functions 'tracking', 'selectFibers' and 'reduceFibers' tensor2medinria Write Tensor Data as NIFTI File medinria2tensor Read Tensor Data from NIFTI File

References

Tabelow, K. and Polzehl, J. and Spokoiny, V. and Voss, H. U. (2008) Diffusion Tensor Imaging: Structural adaptive smoothing, NeuroImage 39(4), 1763--1773.

Polzehl, J. and Tabelow, K. (2008) Structural Adaptive Smoothing in Diffusion Tensor Imaging: the R package dti, WIAS-Preprint 1382.

http://www.wias-berlin.de/projects/matheon_a3/

Examples

Run this code
demo(dti_art)

Run the code above in your browser using DataLab