| Package: |
| dti |
| Version: |
| 1.1-7 |
| Date: |
| 2013-11-21 |
| Authors@R: |
| c(person("Karsten", "Tabelow", role = c("aut", "cre"), email = "karsten.tabelow@wias-berlin.de"), person("Joerg", "Polzehl", role = c("aut"), email = "joerg.polzehl@wias-berlin.de"), person("Felix", "Anker", role = c("ctb"))) |
| Depends: |
| R (>= 2.14.0), awsMethods (>= 1.0-1) |
| Imports: |
| methods, parallel, oro.nifti (>= 0.3.9), oro.dicom, adimpro, gsl, rgl |
| Suggests: |
| quadprog |
| LazyData: |
| TRUE |
| License: |
| GPL (>= 2) |
| Copyright: |
| This package is Copyright (C) 2005-2013 Weierstrass Institute for Applied Analysis and Stochastics. |
| URL: |
| http://www.wias-berlin.de/projects/matheon_a3 |
| Built: |
| R 3.0.2; x86_64-unknown-linux-gnu; 2013-11-25 15:38:06 UTC; unix |
Index:
awssigmc Estimate noise variance for multicoil MR
systems
colqFA FA map color scheme
combineDWIdata Combine two objects of class "dtiData")
dkiTensor-methods Diffusion Kurtosis Imaging (DKI)
dti-package DTI Analysis
dti.smooth-methods Methods for Function 'dti.smooth' in Package
'dti'
dtiIndices-methods Methods for Function 'dtiIndices' in Package
'dti'
dtiTensor-methods Methods for Function 'dtiTensor' in Package
'dti'
dwi-class Class "dwi"
dwi.smooth-methods Smooth DWI data
dwiMixtensor-methods Methods for Function 'dwiMixtensor' in Package
'dti'
dwiQball-methods Methods for Function 'dwiQball' in Package
'dti'
dwiRiceBias-methods Correction for Rician Bias
dwiSqrtODF-methods Methods for positive definite EAP and ODF
estimation in Package 'dti'
extract-methods Methods for Function 'extract' and '[' in
Package 'dti'
getmask-methods Methods for Function 'getmask' in Package 'dti'
getsdofsb-methods Estimate the noise standard deviation
medinria Read/Write Diffusion Tensor Data from/to NIFTI
File
optgrad Optimal gradient directions
optgradients Optimal gradient directions for number of
gradients between 6 and 162
plot-methods Methods for Function 'plot' in Package 'dti'
pmatrix Parallelize columnwise computations on a matrix
using forking (generalizes function 'pvec' from
package 'parallel')
polyeder Polyeders derived from the Icosahedron (icosa0)
by sequential triangulation of surface
triangles
print-methods Methods for Function 'print' in Package 'dti'
readDWIdata Read Diffusion Weighted Data
sdpar-methods Methods for Function 'sdpar' in Package 'dti'
show-methods Methods for Function 'show' in Package 'dti'
show3d-methods Methods for Function 'show3d' in Package 'dti'
showFAColorScale Writes an image with the colqFA colorscale to
disk.
subsetg Create an objects of class "dtiData" containing
only a subset of gradient directions.
summary-methods Methods for Function 'summary' in Package 'dti'
tracking-methods Methods for Function 'tracking' in Package
'dti'
J. Polzehl and K. Tabelow, Beyond the diffusion tensor model: The package dti, Journal of Statistical Software, 44 no. 12 (2011) pp. 1-26.
K. Tabelow, H.U. Voss and J. Polzehl, Modeling the orientation distribution function by mixtures of angular central Gaussian distributions, Journal of Neuroscience Methods, 203 (2012), pp. 200-211.
J. Polzehl and K. Tabelow, Structural adaptive smoothing in diffusion tensor imaging: The R package dti, Journal of Statistical Software, 31 (2009) pp. 1--24. K. Tabelow, J. Polzehl, V. Spokoiny and H.U. Voss. Diffusion Tensor Imaging: Structural adaptive smoothing, NeuroImage 39(4), 1763-1773 (2008).
## Not run: demo(dti_art)
## Not run: demo(mixtens_art)
Run the code above in your browser using DataLab