"dtiData"-object is provided). It also implements structural adaptive smoothing of a diffusion tensor using a Riemannian metric (in case a "dtiTensor"-object is given), although we strictly recommend to use the first variant due to methodological reasons.
"dti.smooth"(object, hmax=5, hinit=NULL, lambda=20, tau=10, rho=1, graph=FALSE,slice=NULL, quant=.8, minfa=NULL, hsig=2.5, lseq=NULL, method="nonlinear", rician=TRUE, niter=5,result="Tensor")"dtiData" or an object of class "dtiTensor"minfa as corresponding quantile of FA if is.null(minfa) lambda"linear", "nonlinear""Tensor" for create a dtiTensor-object and "dtiData"
for a dtiData-object containing a smoothed data cube.dtiTensor.
dti.smooth on DWI data directly, i.e. on an object of class "dtiData", due to methodological reasons, see Tabelow et al. (2008). It is usually not necessary to use any other argument than hmax, which defines the maximum bandwidth of the iteration. If model=="linear" estimates are obtained using a linearization of the tensor model. This was the estimate used in Tabelow et.al. (2008). model=="nonlinear" uses a nonlinear regression model with reparametrization that ensures the tensor to be positive semidefinite, see Koay et.al. (2006). If varmethod=="replicates" the error variance is estimated from replicated gradient directions if possible, otherwise (default) an estimate is obtained from the residual sum of squares. If volseq==TRUE the sum of location weights is fixed to $1.25^k$ within iteration $k$ (does not depend on the actual tensor). Otherwise the ellipsoid of positive location weights is determined by a bandwidth $h_k = 1.25^(k/3)$. K. Tabelow, H.U. Voss and J. Polzehl, Modeling the orientation distribution function by mixtures of angular central Gaussian distributions, Journal of Neuroscience Methods, to appear.
J. Polzehl and K. Tabelow, Structural adaptive smoothing in diffusion tensor imaging: The R package dti, Journal of Statistical Software, 31 (2009) pp. 1--24. K. Tabelow, J. Polzehl, V. Spokoiny and H.U. Voss. Diffusion Tensor Imaging: Structural adaptive smoothing, NeuroImage 39(4), 1763-1773 (2008).
dtiData,
readDWIdata,
dtiTensor-methods,
dtiIndices-methods,
medinria ,
dtiData,
dtiTensor,
dtiIndices