Learn R Programming

dti (version 1.1-0)

dtiIndices-methods: Methods for Function `dtiIndices' in Package `dti'

Description

The method creates estimates of the fractional anisotropy (FA) and relative anisotropy (RA) indices, the main directions of anisotropy and several statistics used for visualization.

Usage

## S3 method for class 'dtiTensor':
dtiIndices(object, which, mc.cores = getOption("mc.cores", 2L))

Arguments

object
Object of class "dtiTensor"
which
Indices should be created, currently not implemented.
mc.cores
Number of cores to use. Defaults to getOption("mc.cores", 2L). This may be larger than the optimal value. Our experience suggests to use 4-6 cores if available.

Value

  • An object of class "dtiIndices".

References

J. Polzehl and K. Tabelow, Beyond the diffusion tensor model: The package dti, Journal of Statistical Software, to appear.

K. Tabelow, H.U. Voss and J. Polzehl, Modeling the orientation distribution function by mixtures of angular central Gaussian distributions, Journal of Neuroscience Methods, to appear.

J. Polzehl and K. Tabelow, Structural adaptive smoothing in diffusion tensor imaging: The R package dti, Journal of Statistical Software, 31 (2009) pp. 1--24. K. Tabelow, J. Polzehl, V. Spokoiny and H.U. Voss. Diffusion Tensor Imaging: Structural adaptive smoothing, NeuroImage 39(4), 1763-1773 (2008).

http://www.wias-berlin.de/projects/matheon_a3/

See Also

medinria, dtiTensor-methods, dtiTensor, dtiIndices

Examples

Run this code
demo(dti_art)

Run the code above in your browser using DataLab