Learn R Programming

dti (version 1.2-4.1)

dwiQball-methods: Methods for Function `dwiQball' in Package `dti'

Description

The method estimates, in each voxel, the coefficients of an expansion of the apparent diffusion cefficient (ADC) with respect to a apherical harmonics orthonormal system from the DWI data contained in an object of class "dtiData".

Usage

"dwiQball"(object, what="wODF", order=4, lambda=0)

Arguments

object
Object of class "dtiData"
what
Determines quantity to estimate, coefficients ot the orientation density function (ODF) (what="ODF", what="wODF", what="aODF") or the apparent diffusion coefficient (ADC) (what="ADC") with respect to spherical harmonics of the up to the specified order.
order
even integer: maximum order of the sperical harmonics expansion
lambda
nonnegative regularization parameter.

Value

An object of class "dwiQball".

Methods

obj = "ANY"
Returns a warning.
obj = "dtiData"
Estimate, in each voxel, the coefficients of an expansion of the orientation density function (ODF) or the apparent diffusion coefficient (ADC) with respect to a apherical harmonics orthonormal system. Note that the maxima of the ADC have no direct interpretation as fibre orientations.

References

M. Descoteaux, E. Angelino, S. Fitzgibbons and R. Deriche, Regularized, Fast and Robust Analytical Q-Ball Imaging, Magnetic Resonance Methods, 2007, 58, 497-512.

See Also

dtiData, readDWIdata, dtiIndices-methods, medinria, dtiData, dtiTensor

Examples

Run this code
  ## Not run: demo(dti_art)

Run the code above in your browser using DataLab