Learn R Programming

dti (version 1.2-4.1)

dwiSqrtODF-methods: Methods for positive definite EAP and ODF estimation in Package dti

Description

Compute a positive definite estimate of the Ensemble Average Propagator (EAP) and Orientation Density Function (ODF) using the approach of Cjeng et. al (2012).

Usage

"dwiSqrtODF"(object,what="sqrtODF",order=4,forder=1,lambda=0,D0=1.4e-3)

Arguments

object
Object of class "dtiData"
what
Character, currently only "sqrtODF" is possible
order
Even integer, Order of spherical harmonics approximation.
forder
Integer, Order of radial approximation.
lambda
Non-negative, Regularization parameter.
D0
Numeric vector, grid of diffusivity parameters, typically about 1e-3.

Methods

signature(object = "ANY")
Returns a warning.
signature(object = "dtiData")
Compute a positive definite estimate of the Ensemble Average Propagator (EAP) and Orientation Density Function (ODF) using the approach of Cjeng et. al (2012).

References

J. Cheng, T. Jiang and R. Deriche. Nonnegative Definite EAP and ODF Estimation via a Unified Multi-Shell HARDI Reconstruction, MICCAI 2012.

See Also

dtiData, readDWIdata, dtiData, dwiQball