dwiSqrtODF-methods: Methods for positive definite EAP and ODF estimation in Package dti
Description
Compute a positive definite estimate of the Ensemble Average Propagator (EAP)
and Orientation Density Function (ODF) using the approach of Cjeng et. al (2012).
Even integer, Order of spherical harmonics approximation.
forder
Integer, Order of radial approximation.
lambda
Non-negative, Regularization parameter.
D0
Numeric vector, grid of diffusivity parameters, typically about 1e-3.
Methods
signature(object = "ANY")
Returns a warning.
signature(object = "dtiData")
Compute a positive definite estimate of the Ensemble Average Propagator (EAP)
and Orientation Density Function (ODF) using the approach of Cjeng et. al (2012).
References
J. Cheng, T. Jiang and R. Deriche.
Nonnegative Definite EAP and ODF Estimation via a Unified Multi-Shell HARDI Reconstruction, MICCAI 2012.